@@ -1,6 +1,7 @@
 import json 
 import boto3
 from io import BytesIO
+import joblib
 import pandas as pd
 
 config_file_path = "credentials.json" 
@@ -24,7 +25,10 @@ def write_data(file_name, data):
 
 def write_model(file_name, data):
     config = _config()
-    _put_object(config, config['bucket_name'], BytesIO(data), file_name)
+    with BytesIO() as f:
+        joblib.dump(data, f)
+        f.seek(0)
+        _put_object(config, config['bucket_name'], f, file_name)
 
 
 def _put_object(config, bucket, body, object_name):
